/*	WebDownloader for X-Window
 *	Copyright (C) 1999-2002 Koshelev Maxim
 *	This Program is free but not GPL!!! You can't modify it
 *	without agreement with author. You can't distribute modified
 *	program but you can distribute unmodified program.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "colors.h"
const GdkColor LBLUE = {
    0, 0xbb00, 0xdd00, 0xffff
};
const GdkColor BLUE = {
    0, 0x0000, 0x0000, 0x8000
};
const GdkColor BLACK = {
    0, 0x0000, 0x0000, 0x0000
};
const GdkColor RED = {
    0, 0x8000, 0x0000, 0x0000
};
const GdkColor LRED = {
    0, 0xffff, 0x5500, 0x5500
};
const GdkColor LCYAN = {
    0, 0xdd00, 0xeeff, 0xffff
};
const GdkColor CYAN = {
    0, 0x4000, 0x6600, 0x8000
};
const GdkColor WHITE = {
    0, 0xffff, 0xffff, 0xffff
};
const GdkColor YELLOW = {
    0, 0xffff, 0x8888, 0x0000
};
const GdkColor LYELLOW = {
    0, 0xffff, 0xffff, 0xcccc
};
const GdkColor LGREEN = {
    0, 0xdd00, 0xffff, 0xdd00
};
const GdkColor GREEN = {
    0, 0x0000, 0x7000, 0x0000
};
const GdkColor GREYCYAN = {
    0, 0xdd00, 0xdd00, 0xee00
};
const GdkColor GREY = {
    0, 0xdd00, 0xdd00, 0xdd00
};
const GdkColor LIGHTGREY = {
    0, 0xee00, 0xee00, 0xee00
};
const GdkColor MIDGREY = {
    0, 0xaa00, 0xaa00, 0xaa00
};
const GdkColor DARKGREY = {
    0, 0x6600, 0x6600, 0x6600
};
